Home
last modified time | relevance | path

Searched refs:__shared__ (Results 1 – 25 of 30) sorted by relevance

12

/llvm-project-15.0.7/clang/test/SemaCUDA/
H A Ddevice-var-init.cu15 __shared__ int s_v_i = 1;
25 __shared__ T s_t_i = {2};
36 __shared__ EC s_ec_i(3);
64 __shared__ UC s_uc;
71 __shared__ UD s_ud;
78 __shared__ ECI s_eci;
85 __shared__ NEC s_nec;
92 __shared__ NED s_ned;
99 __shared__ NCV s_ncv;
106 __shared__ VD s_vd;
[all …]
H A Dextern-shared.cu12 extern __shared__ int x; // expected-error {{__shared__ variable 'x' cannot be 'extern'}} in foo()
13 extern __shared__ int arr[]; // ok in foo()
14 extern __shared__ int arr0[0]; // expected-error {{__shared__ variable 'arr0' cannot be 'extern'}} in foo()
15 extern __shared__ int arr1[1]; // expected-error {{__shared__ variable 'arr1' cannot be 'extern'}} in foo()
16 extern __shared__ int* ptr ; // expected-error {{__shared__ variable 'ptr' cannot be 'extern'}} in foo()
20 extern __shared__ int arr[]; // ok in bar()
21 extern __shared__ int arr0[0]; // expected-error {{__shared__ variable 'arr0' cannot be 'extern'}} in bar()
23 extern __shared__ int* ptr ; // expected-error {{__shared__ variable 'ptr' cannot be 'extern'}} in bar()
27 extern __shared__ int global_arr[]; // ok
35 extern __shared__ int global_arr[]; // rdc-warning {{has internal linkage but is not defined}}
[all …]
H A Dbad-attributes.cu20 __shared__ int d1;
21 __shared__ void d2(); // expected-warning {{attribute only applies to variables}}
30 __device__ __shared__ int z3;
39 __constant__ __shared__ int z8; // expected-error {{attributes are not compatible}}
42 __shared__ __device__ int z9;
43 __shared__ __constant__ int z10; // expected-error {{attributes are not compatible}}
45 __constant__ __shared__ int z10a; // expected-error {{attributes are not compatible}}
68__shared__ int s; // expected-error {{__shared__ local variables not allowed in __host__ functions… in host_fn()
H A Dunion-init.cu39 __shared__ B b; in foo()
40 __shared__ C c; in foo()
42 __shared__ D d; in foo()
H A Dqualifiers.cu24 __shared__ int __thread shared_tls_var; // expected-error {{thread-local storage is not supported f…
31 __shared__ int __thread shared_tls_var;
H A Dmanaged-var.cu28 __managed__ __shared__ int m5;
32 __shared__ __managed__ int m5a;
H A Dattr-declspec.cu27 __declspec(__shared__) float *g_shared;
H A Dconstexpr-var.cu89 __shared__ int b;
H A Dconst-var.cu88 __shared__ int b;
H A Ddevice-use-host-var.cu38 __shared__ int global_shared_var;
/llvm-project-15.0.7/clang/test/CodeGenCUDA/
H A Ddevice-var-init.cu25 __shared__ int s_v;
50 __shared__ T s_t;
68 __shared__ EC s_ec;
79 __shared__ ED s_ed;
89 __shared__ ECD s_ecd;
100 __shared__ ETC s_etc;
118 __shared__ T_B_T s_t_b_t;
129 __shared__ T_F_T s_t_f_t;
140 __shared__ T_FA_T s_t_fa_t;
152 __shared__ EC_I_EC s_ec_i_ec;
[all …]
H A Daddress-spaces.cu16 __shared__ int k;
40 __shared__ int lk; in foo()
46 __shared__ MyStruct a; in func0()
59 __shared__ float a; in func1()
66 __shared__ float a[256]; in func2()
74 __shared__ float a; in func3()
82 __shared__ float a; in func4()
89 __shared__ float b;
H A Ddebug-info-address-class.cu10 __device__ __shared__ int FileVar1;
21 __shared__ int FuncVar0; in kernel1()
H A Dbuiltins-amdgcn.cu53 __shared__ float shared; in test_ds_fmax()
70 __shared__ float shared; in test_ds_fadd()
H A Dfilter-decl.cu22 __shared__ char shareddata[256];
H A Ddevice-stub.cu82 __shared__ int shared_var;
/llvm-project-15.0.7/clang/test/CodeGenHIP/
H A Dhipspv-addr-spaces.cpp5 #define __shared__ __attribute__((shared)) macro
17 __shared__ int s;
/llvm-project-15.0.7/clang/test/CodeGenCUDA/Inputs/
H A Dcuda.h10 #define __shared__ __attribute__((shared)) macro
20 #define __shared__ macro
/llvm-project-15.0.7/clang/test/CodeGen/
H A Dbuiltins-nvptx-ptx50.cu10 #define __shared__ __attribute__((shared)) macro
H A Dbuiltins-nvptx.c28 #define __shared__ __attribute__((shared)) macro
205 __shared__ int si;
207 __shared__ long sl;
209 __shared__ long long sll;
H A Dbuiltins-nvptx-ptx60.cu18 #define __shared__ __attribute__((shared)) macro
/llvm-project-15.0.7/clang/test/PCH/Inputs/
H A Dcuda.h9 #define __shared__ __attribute__((shared)) macro
/llvm-project-15.0.7/clang/test/SemaCUDA/Inputs/
H A Dcuda.h12 #define __shared__ __attribute__((shared)) macro
/llvm-project-15.0.7/clang/lib/Headers/
H A D__clang_hip_runtime_wrapper.h24 #define __shared__ __attribute__((shared)) macro
/llvm-project-15.0.7/clang/test/AST/Inputs/
H A Dcuda.h12 #define __shared__ __attribute__((shared)) macro

12